<?php

namespace Drupal\responsive_voice_tts\Form;

use Drupal\Core\Entity\EntityTypeManagerInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a configuration form for the ResponsiveVoice TTS module.
 */
class ResponsiveVoiceTtsConfigForm extends ConfigFormBase {

  /**
   * The entity type manager service.
   *
   * @var \Drupal\Core\Entity\EntityTypeManagerInterface
   */
  protected $entityTypeManager;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('entity_type.manager')
    );
  }

  public function __construct(EntityTypeManagerInterface $entity_type_manager) {
    $this->entityTypeManager = $entity_type_manager;
  }

  /**
   * {@inheritdoc}
   *
   * This method gets the form ID for this config form.
   *
   * @return string
   *   The unique form ID.
   */
  public function getFormId() {
    return 'responsive_voice_tts_config_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return ['responsive_voice_tts.settings'];
  }

  /**
   * {@inheritdoc}
   *
   * Builds the form elements for configuration.
   *
   * @param array $form
   *   An associative array containing the form structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('responsive_voice_tts.settings');

    $form['api_key'] = [
      '#type' => 'textfield',
      '#title' => $this->t('API Key'),
      '#required' => TRUE,
      '#default_value' => $config->get('api_key'),
      '#description' => $this->t('if you dont have API, you can create one using this link https://app.responsivevoice.org/'),
    ];
    // Get all content types.
    $content_types = $this->entityTypeManager->getStorage('node_type')->loadMultiple();

    // Checkbox options for content types.
    $options = [];
    foreach ($content_types as $content_type) {
      $options[$content_type->id()] = $content_type->label();
    }

    // Add form elements for selecting content types and position.
    $form['content_types'] = [
      '#type' => 'checkboxes',
      '#title' => $this->t('Select content types to enable TTS'),
      '#options' => $options,
      '#default_value' => $config->get('content_types') ?? [],
    ];
    $form['voice_tts'] = [
      '#type' => 'select',
      '#title' => $this->t('Select a Voice'),
      '#options' => [
        'UK English Female' => $this->t('UK English Female'),
        'UK English Male' => $this->t('UK English Male'),
        'US English Female' => $this->t('US English Female'),
        'US English Male' => $this->t('US English Male'),
        'Chinese Female' => $this->t('Chinese Female'),
        'Chinese Male' => $this->t('Chinese Male'),
        'Arabic Female' => $this->t('Arabic Female'),
        'Arabic Male' => $this->t('Arabic Male'),
        'Australian Female' => $this->t('Australian Female'),
        'Australian Male' => $this->t('Australian Male'),
        'Hindi Female' => $this->t('Hindi Female'),
        'Hindi Male' => $this->t('Hindi Male'),
        'French Female' => $this->t('French Female'),
        'French Male' => $this->t('French Male'),
      ],
      '#default_value' => $config->get('voice_tts') ?? 'UK English Female',
      '#required' => TRUE,
    ];

    $form['text_for_play_button'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Audio Play Button Text'),
      '#default_value' => $config->get('text_for_play_button') ?? $this->t('Prefer listening? Hear this article now!'),
      '#description' => $this->t('This text will appear alongside the speaker icon to prompt users to listen to the post. It will be displayed on top or bottom of the selected content types.'),
      '#required' => TRUE,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   *
   * Submit the form elements for configuration.
   *
   * @param array $form
   *   An associative array containing the form structure.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config('responsive_voice_tts.settings')
      ->set('api_key', $form_state->getValue('api_key'))
      ->set('content_types', array_filter($form_state->getValue('content_types')))
      ->set('text_for_play_button', $form_state->getValue('text_for_play_button'))
      ->set('voice_tts', $form_state->getValue('voice_tts'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
